@@ -22,7 +22,7 @@ use overload
     'cmp'	=> '_compare_overload',
     ;
 
-our $VERSION = '0.903_01';
+our $VERSION = '0.904_01';
 
 {
 
@@ -471,7 +471,8 @@ L<DateTime::Duration|DateTime::Duration>
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https:rt.cpan.org>, or in electronic mail to the author.
+L<https://github.com/trwyant/perl-DateTime-Fiction-JRRTolkien-Shire/issues>,
+or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -479,7 +480,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2017-2020 by Thomas R. Wyant, III
+Copyright (C) 2017-2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
